``zope.index``
==============

.. image:: https://img.shields.io/pypi/v/zope.index.svg
    :target: https://pypi.python.org/pypi/zope.index/
    :alt: Latest Version

.. image:: https://travis-ci.org/zopefoundation/zope.index.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.index

The ``zope.index`` package provides several indices for the Zope
catalog.  These include:

* a field index (for indexing orderable values),

* a keyword index,

* a topic index,

* a text index (with support for lexicon, splitter, normalizer, etc.)
